praatio API documentation

# praatio

Praatio is a library for working praat files and audio data.

Praat is a popular tool for working with transcribed speech data. It has tools for annotating speech, manipulating speech, and extracting information from speech. Praat's homepage: http://www.fon.hum.uva.nl/praat/

praatio's utility comes from the classes Textgrid, IntervalTier, and PointTier in textgrid.py These classes represent the speech transcript data stored inside of .TextGrid files. textgrid.py contains functions for reading/writing these objects from/to files. data_points.py and klattgrid.py contain similar code for other data files that praat works with.

pitch_and_intensity.py uses praat to extract pitch and intensity values from audio using praat.

praat_scripts.py enables one to run various praat scripts from within python. If preferred, one can access the praatScripts/ directory to view and edit the praat scripts or open them directly in praat. They can all be run independentlyof python.

audio.py is for reading, reading, and performing simple manipulations to wave files.

praatio_scripts.py contains code that combines various code in praatio--mostly high-level functions for working with textgrids, sometimes in conjuction with audio files.

For example scripts that use various parts of the praatio library, please see 'examples/' in the root directory. If you downloaded praatio from pip, you can get the example files on the praatio github page: https://github.com/timmahrt/praatIO

There is also a tutorial for working with praatio on the github page.

View Source

     1"""
     2Praatio is a library for working praat files and audio data.
     3
     4Praat is a popular tool for working with transcribed speech data.
     5It has tools for annotating speech, manipulating speech, and extracting
     6information from speech.
     7Praat's homepage: [http://www.fon.hum.uva.nl/praat/](http://www.fon.hum.uva.nl/praat/)
     8
     9praatio's utility comes from the classes Textgrid, IntervalTier,
    10and PointTier in **textgrid.py** These classes represent the speech transcript
    11data stored inside of .TextGrid files.  textgrid.py contains functions for
    12reading/writing these objects from/to files. **data_points.py** and **klattgrid.py**
    13contain similar code for other data files that praat works with.
    14
    15**pitch_and_intensity.py** uses praat to extract pitch and intensity values
    16from audio using praat.
    17
    18**praat_scripts.py** enables one to run various praat scripts from within python.
    19If preferred, one can access the **praatScripts/** directory to view and edit the
    20praat scripts or open them directly in praat. They can all be run independentlyof python.
    21
    22**audio.py** is for reading, reading, and performing simple manipulations to wave files.
    23
    24**praatio_scripts.py** contains code that combines various code in praatio--mostly
    25high-level functions for working with textgrids, sometimes in conjuction with audio files.
    26
    27For example scripts that use various parts of the praatio library, please see 'examples/'
    28in the root directory. If you downloaded praatio from pip, you can get the example files
    29on the praatio github page:
    30[https://github.com/timmahrt/praatIO](https://github.com/timmahrt/praatIO)
    31
    32There is also a tutorial for working with praatio on the github page.
    33"""
    34
    35__all__ = [
    36    "audio",
    37    "data_points",
    38    "klattgrid",
    39    "pitch_and_intensity",
    40    "praat_scripts",
    41    "praatio_scripts",
    42    "textgrid",
    43    "data_classes",
    44    "utilities",
    45]